@@ -43,6 +43,7 @@ def generate_sqs_event(
     return {
         "Records": [
             {
+                "eventSource": "aws:sqs",
                 "messageId": md5(json.dumps(body).encode()),
                 "body": json.dumps(envelope(body, metadata)),
             }
@@ -51,12 +52,15 @@ def generate_sqs_event(
 
 
 def generate_api_gateway_event(
+    resource: Optional[str] = None,
+    method: Optional[str] = None,
     body: Optional[Union[dict[str, Any], str]] = None,
     path_parameters: Optional[dict[str, str]] = None,
     query_parameters: Optional[dict[str, str]] = None,
     caller_account_id: Optional[str] = None,
     jwt_claims: Optional[dict[str, Any]] = None,
     jwt_scopes: Optional[list[str]] = None,
+    jwt_context: Optional[dict[str, Any]] = None,
     headers: Optional[dict[str, str]] = None,
 ) -> dict[str, Any]:
     headers = headers or {}
@@ -69,21 +73,33 @@ def generate_api_gateway_event(
         except json.JSONDecodeError:
             body = body
 
-    return {
+    event = {
+        "resource": resource,
+        "httpMethod": method,
         "body": body,
         "pathParameters": path_parameters,
         "queryStringParameters": query_parameters,
         "requestContext": {
             "identity": {"accountId": caller_account_id},
-            "authorizer": {"claims": jwt_claims, "scopes": jwt_scopes},
+            "authorizer": {
+                "claims": jwt_claims,
+                "scopes": jwt_scopes,
+                # authorization context details injected by a Lambda Authorizer
+                **(jwt_context if jwt_context is not None else {}),
+            },
         },
         "headers": headers,
     }
 
+    return event
+
 
 def generate_api_gateway_event_without_jwt(
+    resource: Optional[str] = None,
+    method: Optional[str] = None,
     body: Optional[Union[dict[str, Any], str]] = None,
     path_parameters: Optional[dict[str, str]] = None,
+    query_parameters: Optional[dict[str, str]] = None,
     caller_account_id: Optional[str] = None,
     headers: Optional[dict[str, str]] = None,
 ) -> dict[str, Any]:
@@ -98,8 +114,11 @@ def generate_api_gateway_event_without_jwt(
             body = body
 
     return {
+        "resource": resource,
+        "httpMethod": method,
         "body": body,
         "pathParameters": path_parameters,
+        "queryStringParameters": query_parameters,
         "requestContext": {
             "identity": {"accountId": caller_account_id},
         },
@@ -107,11 +126,24 @@ def generate_api_gateway_event_without_jwt(
     }
 
 
-def generate_dynamodb_event(old_value: Optional[dict[str, Any]]) -> dict[str, Any]:
+def generate_dynamodb_event(
+    old_value: Optional[dict[str, Any]],
+    table_name: str,
+    aws_region: str = "eu-west-1",
+    aws_account_id: str = "123456789012",
+) -> dict[str, Any]:
     ts = TypeSerializer()
+
+    stream_arn = (
+        f"arn:aws:dynamodb:{aws_region}:{aws_account_id}"
+        f":table/{table_name}/stream/2024-12-01T00:00:00.000"
+    )
+
     return {
         "Records": [
             {
+                "eventSource": "aws:dynamodb",
+                "eventSourceARN": stream_arn,
                 "dynamodb": {
                     # We don't care about the sequence number, but it is needed
                     "SequenceNumber": md5(str(datetime.now()).encode()),
@@ -125,7 +157,7 @@ def generate_dynamodb_event(old_value: Optional[dict[str, Any]]) -> dict[str, An
                     }
                     if old_value is not None
                     else {},
-                }
+                },
             }
         ]
     }
